using System;
using System.Windows.Forms;
using Demo.Model;
using Demo.Model.Interfaces;
using Demo.View.UserControls;
using Infragistics.Win.UltraWinExplorerBar;

namespace Demo.Presenter
{
    public class MasterPresenter
    {
        private readonly string _plainTextDefault = "This is an application that communicates securely with a known application."
                                                    + Environment.NewLine + Environment.NewLine
                                                    + "It provides speed and security that can be built into the system that helps a fast, "
                                                    + "secure and reliable communication from one machine to another."
                                                    + Environment.NewLine + Environment.NewLine
                                                    +
                                                    "It protects data on your system securely with tamper detection built in at the same time.";

        private IDemoTypePresenter _typePresenter;
        private readonly IMasterView _view;
        private const string FeatureVariation = "variation";

        public MasterPresenter(IMasterView view)
        {
            _view = view;
            createEventHandlers();
            initializeMasterWindow();
        }

        public MasterPresenter() {}

        private void activateFeatureType(string key)
        {

            CipherMaster panel = new CipherVariation();
            FeaturesMaster features = new FeaturesVariation();
            _typePresenter = new PresenterVariation(_view, panel, features);

            _typePresenter.Activate();
            clearDecryptedText();
        }

        private void clearDecryptedText()
        {
            _view.TxtDecryptedText = string.Empty;
        }

        private void createEventHandlers()
        {
            _view.ViewClosed += mainAppView_ViewClosed;
            _view.FeatureSelected += featureSelected;
            _view.PlainTextChanged += plainTextChanged;
        }

        private void featureSelected(object sender, ItemEventArgs e)
        {
//            highlightSelectedFeature(e);
            activateFeatureType(e.Item.Key);
            rewriteTitleBarWithFeature(e.Item.Key);
        }

        private void highlightSelectedFeature(ItemEventArgs e)
        {
            UltraExplorerBarGroup explorerBarGroup = e.Item.Group;
            foreach (UltraExplorerBarItem item in explorerBarGroup.Items) {}
        }

        private void initializeMasterWindow()
        {
            _view.TxtPlainText = _plainTextDefault;
            activateFeatureType(FeatureVariation);
            rewriteTitleBarWithFeature(FeatureVariation);
            _view.Show();
        }

        private static void mainAppView_ViewClosed(object sender, EventArgs e)
        {
            Application.Exit();
        }

        private void plainTextChanged(object sender, EventArgs e)
        {
            clearDecryptedText();
        }

        private void rewriteTitleBarWithFeature(string feature)
        {
            _view.DemoTitleBar = "MainStreamEncryption Demo - " + feature.Substring(0, 1).ToUpper() +
                                 feature.Substring(1, feature.Length - 1);
        }
    }
}