﻿using System;
using System.Windows.Forms;
using Demo.Model;
using Infragistics.Win.UltraWinExplorerBar;

namespace Demo.View
{
    public partial class MasterForm : Form, IMasterView
    {
        public MasterForm()
        {
            InitializeComponent();
            setupEventHandlers();
            setupToolTips();
        }

        public string DemoTitleBar
        {
            set { Text = value; }
        }

        public bool EnableNextStorySlide
        {
            set { btnNext.Enabled = value; }
        }

        public bool EnablePreviousStorySlide
        {
            set { btnPrevious.Enabled = value; }
        }

        public Panel PnlCipher
        {
            get { return pnlCipher; }
        }

        public Panel PnlFeatures
        {
            get { return pnlFeatures; }
        }

        public PictureBox StoryBox
        {
            get { return storyBox; }
        }

        public string TxtDecryptedText
        {
            get { return txtDecryptedText.Text; }
            set { txtDecryptedText.Text = value; }
        }

        public string TxtKey
        {
            get { return txtKey.Text; }
            set { txtKey.Text = value; }
        }

        public string TxtPlainText
        {
            get { return txtPlainText.Text; }
            set { txtPlainText.Text = value; }
        }

        public string TxtRandom
        {
            get { return txtRandom.Text; }
            set { txtRandom.Text = value; }
        }

        public event EventHandler<ItemEventArgs> FeatureSelected;
        public event EventHandler<EventArgs> PlainTextChanged;
        public event EventHandler<EventArgs> RandomTextChanged;
        public event EventHandler<EventArgs> StoryNextClicked;
        public event EventHandler<EventArgs> StoryPreviousClicked;
        public event EventHandler<EventArgs> ViewClosed;

        private void btnNext_Click(object sender, EventArgs e)
        {
            if (StoryNextClicked != null)
            {
                StoryNextClicked(sender, e);
            }
        }

        private void btnPrevious_Click(object sender, EventArgs e)
        {
            if (StoryPreviousClicked != null)
            {
                StoryPreviousClicked(sender, e);
            }
        }

        private void setupEventHandlers()
        {
            Closed += delegate { ViewClosed(this, new EventArgs()); };
            txtPlainText.TextChanged += txtPlainText_TextChanged;
            btnNext.Click += btnNext_Click;
            btnPrevious.Click += btnPrevious_Click;
            txtRandom.TextChanged += txtRandom_TextChanged;
        }

        private void setupToolTips()
        {
            ToolTip tt = new ToolTip
                         {
                             AutoPopDelay = 5000,
                             InitialDelay = 1000,
                             ReshowDelay = 500
                         };
            tt.SetToolTip(txtRandom, "Enter a percent between 1 and 1000");
        }

        private void txtPlainText_TextChanged(object sender, EventArgs e)
        {
            PlainTextChanged(sender, e);
        }

        private void txtRandom_TextChanged(object sender, EventArgs e)
        {
            if (RandomTextChanged != null)
            {
                RandomTextChanged(sender, e);
            }
        }

        private void ultraExplorerBar1_ItemClick(object sender, ItemEventArgs e)
        {
            FeatureSelected(this, e);
        }
    }
}